Please open a new issue or new pull request for bugs, feedback, or new features
you would like to see. If there is an issue you would like to work on, please
leave a comment and we will be happy to assist. New contributions and
contributors are very welcome!

The main development work is done on the "master" branch. The "stable" branch is
protected and used for official releases. The rest of the branches are for
release maintenance and should not be used normally. Unless otherwise told by a
maintainer, pull request should be made and submitted to the "master" branch.

New to github or open source projects? If you are unsure about where to start or
haven't used github before, please feel free to contact the package maintainers.

Feedback and feature requests? Is there something missing you would like to see?
Please open an issue or send an email to the maintainers. This package follows
the Spacetelescope `Code of Conduct<CODE_OF_CONDUCT.md>`_ strives to provide a
welcoming community to all of our users and contributors.
